==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/EventHookFilterMapObject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EventHookFilterMapObjectCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EventHookFilterMapObject
 */
@JsonPropertyOrder({ EventHookFilterMapObject.JSON_PROPERTY_CONDITION, EventHookFilterMapObject.JSON_PROPERTY_EVENT })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EventHookFilterMapObject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONDITION = "condition";
    private EventHookFilterMapObjectCondition condition;

    public static final String JSON_PROPERTY_EVENT = "event";
    private String event;

    public EventHookFilterMapObject() {
    }

    public EventHookFilterMapObject condition(EventHookFilterMapObjectCondition condition) {

        this.condition = condition;
        return this;
    }

    /**
     * Get condition
     *
     * @return condition
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONDITION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EventHookFilterMapObjectCondition getCondition() {
        return condition;
    }

    @JsonProperty(JSON_PROPERTY_CONDITION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCondition(EventHookFilterMapObjectCondition condition) {
        this.condition = condition;
    }

    public EventHookFilterMapObject event(String event) {

        this.event = event;
        return this;
    }

    /**
     * The filtered event type
     *
     * @return event
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The filtered event type")
    @JsonProperty(JSON_PROPERTY_EVENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEvent() {
        return event;
    }

    @JsonProperty(JSON_PROPERTY_EVENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEvent(String event) {
        this.event = event;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EventHookFilterMapObject eventHookFilterMapObject = (EventHookFilterMapObject) o;
        return Objects.equals(this.condition, eventHookFilterMapObject.condition)
                && Objects.equals(this.event, eventHookFilterMapObject.event);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(condition, event);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EventHookFilterMapObject {\n");
        sb.append("    condition: ").append(toIndentedString(condition)).append("\n");
        sb.append("    event: ").append(toIndentedString(event)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/EventHookFilterMapObject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EventHookFilterMapObjectCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EventHookFilterMapObject
 */
@JsonPropertyOrder({ EventHookFilterMapObject.JSON_PROPERTY_CONDITION, EventHookFilterMapObject.JSON_PROPERTY_EVENT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class EventHookFilterMapObject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONDITION = "condition";
    private EventHookFilterMapObjectCondition condition;

    public static final String JSON_PROPERTY_EVENT = "event";
    private String event;

    public EventHookFilterMapObject() {
    }

    public EventHookFilterMapObject condition(EventHookFilterMapObjectCondition condition) {

        this.condition = condition;
        return this;
    }

    /**
     * Get condition
     *
     * @return condition
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONDITION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EventHookFilterMapObjectCondition getCondition() {
        return condition;
    }

    @JsonProperty(JSON_PROPERTY_CONDITION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCondition(EventHookFilterMapObjectCondition condition) {
        this.condition = condition;
    }

    public EventHookFilterMapObject event(String event) {

        this.event = event;
        return this;
    }

    /**
     * The filtered event type
     *
     * @return event
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The filtered event type")
    @JsonProperty(JSON_PROPERTY_EVENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEvent() {
        return event;
    }

    @JsonProperty(JSON_PROPERTY_EVENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEvent(String event) {
        this.event = event;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EventHookFilterMapObject eventHookFilterMapObject = (EventHookFilterMapObject) o;
        return Objects.equals(this.condition, eventHookFilterMapObject.condition)
                && Objects.equals(this.event, eventHookFilterMapObject.event);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(condition, event);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EventHookFilterMapObject {\n");
        sb.append("    condition: ").append(toIndentedString(condition)).append("\n");
        sb.append("    event: ").append(toIndentedString(event)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
